@@ -11,17 +11,16 @@ from .provider import KakaoProvider
 
 class KakaoOAuth2Adapter(OAuth2Adapter):
     provider_id = KakaoProvider.id
-    access_token_url = 'https://kauth.kakao.com/oauth/token'
-    authorize_url = 'https://kauth.kakao.com/oauth/authorize'
-    profile_url = 'https://kapi.kakao.com/v2/user/me'
+    access_token_url = "https://kauth.kakao.com/oauth/token"
+    authorize_url = "https://kauth.kakao.com/oauth/authorize"
+    profile_url = "https://kapi.kakao.com/v2/user/me"
 
     def complete_login(self, request, app, token, **kwargs):
-        headers = {'Authorization': 'Bearer {0}'.format(token.token)}
+        headers = {"Authorization": "Bearer {0}".format(token.token)}
         resp = requests.get(self.profile_url, headers=headers)
         resp.raise_for_status()
         extra_data = resp.json()
-        return self.get_provider().sociallogin_from_response(request,
-                                                             extra_data)
+        return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
 oauth2_login = OAuth2LoginView.adapter_view(KakaoOAuth2Adapter)
